@@ -15,7 +15,14 @@ FORMAT = "%(message)s"
 
 
 @app.callback()
-def main(verbose: bool = False):
+def main(
+    verbose: bool = typer.Option(
+        False,
+        "--verbose",
+        "-v",
+        help="Put out more details on the event stream meta events.",
+    )
+):
     level = "WARNING"
     if verbose:
         level = "DEBUG"
