@@ -43,3 +43,8 @@ class Fact(BaseModel):
         return cls(
             header=json.loads(msg.fact.header), payload=json.loads(msg.fact.payload)
         )
+
+
+class VersionedType(BaseModel):
+    type: str
+    version: int = 0
