@@ -3,7 +3,7 @@ import logging
 import grpc
 import struct
 from types import TracebackType
-from typing import Iterable, List, Optional, Type
+from typing import Dict, Iterable, List, Optional, Type, Union
 from json import dumps
 from uuid import UUID
 
@@ -24,7 +24,7 @@ from pyfactcast.client.config import (
     get_client_configuration,
     log_level,
 )
-from pyfactcast.client.entities import Fact
+from pyfactcast.client.entities import Fact, VersionedType
 
 log = logging.getLogger()
 log.setLevel(log_level)
@@ -142,12 +142,15 @@ class FactStore:
         continuous: bool = False,
         from_now: bool = False,
         after_fact: UUID = None,
-        fact_types: Iterable[str] = [],
+        fact_types: Iterable[VersionedType] = [],
     ) -> Iterable[Fact]:
 
-        specs = [{"ns": namespace}]
+        specs: List[Dict[str, Union[str, int]]] = [{"ns": namespace}]
         if fact_types:
-            specs = [{"ns": namespace, "type": fact_type} for fact_type in fact_types]
+            specs = [
+                {"ns": namespace, "type": fact_type.type, "version": fact_type.version}
+                for fact_type in fact_types
+            ]
 
         subscription_request_body = {
             "specs": specs,
